@@ -195,17 +195,17 @@ bool is_first_instance(char* flock)
 int  AskUserToSaveFile(char* name)
 {
   if( !TheApp)
-    return IDNO;
+    return VDK_IDNO;
   char local[256];
   VDKString Yes = CHECK_YES;
   if(VDKBuilder::ideDefaults.project.autosave == Yes)
-    return IDYES;
+    return VDK_IDYES;
   sprintf(local,"%s\n%s",name,
 	  _(user_messages[user_request_save])
 	  );
-  return TheApp->MessageBox(APPNAME,
+  return TheApp->VDKMessageBox(APPNAME,
 			    local,
-			    MB_ICONQUESTION|MB_YESNO,
+			    VDK_ICONQUESTION|VDK_YESNO,
 			    _(user_messages[user_ok]),
 			    _(user_messages[user_no])
 			    );
@@ -618,10 +618,10 @@ VDKBMainForm::LoadTokens()
   sprintf(buff,"%s/.vdkb2/%s",(char*) TheApp->user_home,VDKB_TOKENS_FILE);
   if(access(buff,F_OK))
     {
-      TheApp->MessageBox(APPNAME,
+      TheApp->VDKMessageBox(APPNAME,
 _("User file for completions not found\n\
 reverting to default one"),
-			 MB_ICONINFORMATION|MB_OK,
+			 VDK_ICONINFORMATION|VDK_OK,
 			 _(user_messages[user_ok])
 			 );
       sprintf(buff,"%s/%s",VDKB_DATADIR,VDKB_TOKENS_FILE);
@@ -710,9 +710,9 @@ VDKBMainForm::Setup()
   // load token list from file
   tokenlist = new TokenList;
   if(!LoadTokens())
-    TheApp->MessageBox(APPNAME,
+    TheApp->VDKMessageBox(APPNAME,
       _("Completion list not loaded\ncompletion won't be available"),
-		       MB_ICONINFORMATION|MB_OK,
+		       VDK_ICONINFORMATION|VDK_OK,
 		       _(user_messages[user_ok]),
 		       NULL,
 		       3000
@@ -722,9 +722,9 @@ VDKBMainForm::Setup()
   // load hints tree for text editor
   hint_tree = new HintBTree;
   if(!LoadHints())
-    TheApp->MessageBox(APPNAME,
+    TheApp->VDKMessageBox(APPNAME,
       _("Hints tree not loaded\neditor hints won't be available"),
-		       MB_ICONINFORMATION|MB_OK,
+		       VDK_ICONINFORMATION|VDK_OK,
 		       _(user_messages[user_ok])
 		       );
 
@@ -771,8 +771,8 @@ else if(child == maker)
 	    sprintf(buff,_("VDKBuilder maker terminated %s"),
 		    list->size() ? _("with errors or messages") : 
 			   _("successfully"));
-	    Application()->MessageBox(APPNAME,buff,
-				      MB_OK| MB_ICONINFORMATION,
+	    Application()->VDKMessageBox(APPNAME,buff,
+				      VDK_OK| VDK_ICONINFORMATION,
 				      _(user_messages[user_ok]),
 				      NULL, 1500);
 	    // if list size == 0 then no erros, so
@@ -1600,17 +1600,17 @@ bool
 VDKBMainForm::CanClose()
 {
 int answer =
-  Application()->MessageBox(
+  Application()->VDKMessageBox(
 	APPNAME,
 	_(user_messages[user_can_close]),
-	MB_YESNO| MB_ICONQUESTION,
+	VDK_YESNO| VDK_ICONQUESTION,
 	_(user_messages[user_ok]),
 	_(user_messages[user_no]),
 	6000); /*  after 6 seconds without answer
 		   closes with IDNO */
 // closes project manager,editor
 // and mozilla (if activated)
-if(answer == IDYES)
+if(answer == VDK_IDYES)
    {
      // saves last position that will be used
      // by project manager on SaveLastSession()
@@ -1641,11 +1641,11 @@ if(answer == IDYES)
 	if( tklist_size != tokenlist->size() )
 	  {
 	    sprintf(buff,_("Completion list has been changed\n Save it ?"));
-	    if (TheApp->MessageBox(APPNAME,
+	    if (TheApp->VDKMessageBox(APPNAME,
 				   buff,
-				   MB_ICONQUESTION|MB_YESNO,
+				   VDK_ICONQUESTION|VDK_YESNO,
 				   _(user_messages[user_ok]),
-				   _(user_messages[user_no])) == IDYES)
+				   _(user_messages[user_no])) == VDK_IDYES)
 	      {
 		SaveTokens();
 	      }
@@ -1656,7 +1656,7 @@ if(answer == IDYES)
     if(EmacsServerStarted())
       kill(EmacsPid(),SIGTERM);
    }
-return answer == IDYES;
+return answer == VDK_IDYES;
 }
 /*
  */
