@@ -401,9 +401,9 @@ Vdkb_EnvForm::CanClose(void)
 {
   if (Changed && !forceToClose)
     {
-      int result = Application ()->MessageBox(APPNAME,
+      int result = Application ()->VDKMessageBox(APPNAME,
 	   _("Options changed,  save ?"), 
-          MB_ICONQUESTION|MB_YESNO, NULL, NULL, 7000) ==  IDYES;
+          VDK_ICONQUESTION|VDK_YESNO, NULL, NULL, 7000) ==  VDK_IDYES;
       // save changes
       if(result)
 	SaveEnvironment();
@@ -617,10 +617,10 @@ Vdkb_EnvForm::OnsyntfontActivate (VDKObject* sender)
       else
 	{
 	  sprintf(buff,_("font:\"%s\" not available or mispelled"),font);
-	  Application()->MessageBox(
+	  Application()->VDKMessageBox(
 			      APPNAME,
 			      buff,
-			      MB_ICONSTOP|MB_OK,
+			      VDK_ICONSTOP|VDK_OK,
 			      _(user_messages[user_ok]),
 			      NULL,
 			      5000);
@@ -776,9 +776,9 @@ Vdkb_EnvForm::SaveEnvironment()
 \ncopy %s there\
 \n(operation aborted)"),
 	      local,(char*) home,(char*) rcfile);
-      Application()->MessageBox(APPNAME,
+      Application()->VDKMessageBox(APPNAME,
 				buff,
-				MB_ICONINFORMATION|MB_OK,
+				VDK_ICONINFORMATION|VDK_OK,
 				_(user_messages[user_ok]));
       return;
     }
