@@ -658,9 +658,9 @@ VDKBProjectManager::WriteGuiFiles(bool ask)
 		   char *msg = new char[512];
 		   sprintf(msg,"*** WARNING ***,\n\
 attempt to overwrite <%s>\nwith <%s>\noperation aborted",local,copy);
-		   Application()->MessageBox(APPNAME,
+		   Application()->VDKMessageBox(APPNAME,
 				msg,
-				MB_ICONINFORMATION|MB_OK,
+				VDK_ICONINFORMATION|VDK_OK,
 				_(user_messages[user_ok]));
 		   delete[] msg;
 		 }
@@ -692,5 +692,5 @@ extern int  AskUserToSaveFile(char* name);
 bool
 VDKBProjectManager::AskSaveForm(char* name)
 {
-  return AskUserToSaveFile(name) == IDYES;
+  return AskUserToSaveFile(name) == VDK_IDYES;
 }
