@@ -825,7 +825,7 @@ for(;li;li++)
     if(li.current()->Changed)
       {
 	sprintf(buff,"%s",(char*) li.current()->Filename());
-	if(AskUserToSaveFile(buff) == IDYES)
+	if(AskUserToSaveFile(buff) == VDK_IDYES)
 	  {
 	    // never saved
 	    // it's a new unit, changes sentinel in .h
@@ -956,7 +956,7 @@ else
 if(text->Changed)
   {
     sprintf(buff,"%s", (char*) text->Filename());
-    if(AskUserToSaveFile(buff) == IDYES)
+    if(AskUserToSaveFile(buff) == VDK_IDYES)
       {
 	// never saved
 	if(access(text->Filename(),F_OK))
@@ -1262,11 +1262,11 @@ VDKBEditor::RepeatSearch(VDKObject*)
 	  );
   if(pos >= 0)
     last_pos = pos+strlen(match);
-  else if(Application()->MessageBox(APPNAME,
+  else if(Application()->VDKMessageBox(APPNAME,
 				 buff,
-				 MB_ICONQUESTION|MB_YESNO,
+				 VDK_ICONQUESTION|VDK_YESNO,
 				 _(user_messages[user_ok]),
-				 _(user_messages[user_no])) == IDYES)
+				 _(user_messages[user_no])) == VDK_IDYES)
     {
       last_pos = 0;
       RepeatSearch(NULL);
