@@ -96,9 +96,9 @@ VDKBEventBox:: DelBox(VDKObject* sender)
   if(cantDelete)
     {
     //FIX ME: lang support
-      Owner()->Application()->MessageBox(APPNAME,
+      Owner()->Application()->VDKMessageBox(APPNAME,
 			 _("Embedded boxes shouldn't be deleted"),
-			  MB_ICONINFORMATION|MB_OK,
+			  VDK_ICONINFORMATION|VDK_OK,
 			  _(user_messages[user_ok]));
       return true;
     }
@@ -786,11 +786,11 @@ VDKBEventBox::OnSetEventBox(VDKObject*)
   VDKString True = CHECK_TRUE;
   if(evboxCb->Checked && (GetProp(DOCKABLE) == True))
     {
-      Owner()->Application()->MessageBox(
+      Owner()->Application()->VDKMessageBox(
 					 APPNAME,
 _("Dockable and EventBox properties are\n\
 mutually exclusive,\nEventBox won't be changed"),
-					 MB_ICONINFORMATION|MB_OK,
+					 VDK_ICONINFORMATION|VDK_OK,
 					 _(user_messages[user_ok]),
 					 NULL,
 					 5000);
@@ -811,11 +811,11 @@ VDKBEventBox::OnSetDockable(VDKObject*)
   VDKString True = CHECK_TRUE;
   if(dockCb->Checked &&(GetProp(EVENTAWARE) == True))
     {
-      Owner()->Application()->MessageBox(
+      Owner()->Application()->VDKMessageBox(
 					 APPNAME,
 _("Dockable and EventBox properties are\n\
 mutually exclusive\nDockable won't be changed"),
-					 MB_ICONINFORMATION|MB_OK,
+					 VDK_ICONINFORMATION|VDK_OK,
 					 _(user_messages[user_ok]),
 					 NULL,
 					 5000);
