@@ -719,8 +719,8 @@ VDKBGuiForm::OnButtonPress(VDKObject* sender, GdkEvent* ev)
 	    }
 	  // adding failed
 	  if(result)
-	    Application()->MessageBox(APPNAME,buff,
-				      MB_OK| MB_ICONINFORMATION,
+	    Application()->VDKMessageBox(APPNAME,buff,
+				      VDK_OK| VDK_ICONINFORMATION,
 				      (user_messages[user_ok]),
 				      NULL, 2000);
 	  // reset all selection at operation end
@@ -1878,9 +1878,9 @@ VDKBGuiForm::HandleCutAndPaste(VDKObject* sender, GdkEvent* ev)
 	    {
 	      // copying containers isn't allowed
 	      if(dynamic_cast<VDKBEventContainer*>(Active))
-		Application()->MessageBox(APPNAME,
+		Application()->VDKMessageBox(APPNAME,
 		       _("Copying containers isn't allowed"),
-		       MB_ICONINFORMATION|MB_OK,
+		       VDK_ICONINFORMATION|VDK_OK,
 		       _(user_messages[user_ok]),
 		       NULL,
 		       3000
