@@ -320,18 +320,18 @@ VDKBMainForm::RunMozilla(VDKObject*, char* html)
 	      }
 		break;
             case -1:
-	      app->MessageBox(APPNAME,
+	      app->VDKMessageBox(APPNAME,
 			      _("Forking for browser unsuccessfull"),
-			      MB_ICONINFORMATION|MB_OK,
+			      VDK_ICONINFORMATION|VDK_OK,
 			      _(user_messages[user_ok]));
 	      break;
             default:
 	      // help_index->Enabled = false;
 	      help_vdk->Enabled = false;
 	      sprintf(buff, _("Started browser (pid %d)"), mozpid);
-	      Application()->MessageBox(APPNAME,
+	      Application()->VDKMessageBox(APPNAME,
 			      buff,
-			      MB_ICONINFORMATION|MB_OK,
+			      VDK_ICONINFORMATION|VDK_OK,
 			      _(user_messages[user_ok]),NULL,3000);
 	      break;
         }
@@ -455,10 +455,10 @@ VDKBMainForm::RunGrep(VDKObject* sender)
       chdir( (char*) cwd);
     }
   else
-      Application()->MessageBox(
+      Application()->VDKMessageBox(
 				APPNAME,
 				_("A compilation process is already running"),
-				MB_ICONINFORMATION|MB_OK,
+				VDK_ICONINFORMATION|VDK_OK,
 				_(user_messages[user_ok]),
 				NULL,
 				3000);
@@ -603,10 +603,10 @@ VDKBMainForm::RunExecutable()
 	  chdir( (char*) cwd);
 	}
       else
-	Application()->MessageBox(
+	Application()->VDKMessageBox(
 			APPNAME,
 			_("A compilation process is already running"),
-			MB_ICONINFORMATION|MB_OK,
+			VDK_ICONINFORMATION|VDK_OK,
 			_(user_messages[user_ok]),
 			NULL,
 			3000);
@@ -653,10 +653,10 @@ VDKBMainForm::RunDebugger(VDKObject*)
       chdir( (char*) cwd);
     }
   else
-    Application()->MessageBox(
+    Application()->VDKMessageBox(
 			      APPNAME,
 			      _("A compilation process is already running"),
-			      MB_ICONINFORMATION|MB_OK,
+			      VDK_ICONINFORMATION|VDK_OK,
 			      _(user_messages[user_ok]),
 			      NULL,
 			      3000);
@@ -677,9 +677,9 @@ VDKBMainForm::CallEmacsServer(VDKObject*)
     {
       int pid = StartEmacs(args);
       if(pid <= 0)
-	TheApp->MessageBox(APPNAME,
+	TheApp->VDKMessageBox(APPNAME,
 			   _("Emacs server failed"),
-			   MB_ICONINFORMATION|MB_OK,
+			   VDK_ICONINFORMATION|VDK_OK,
 			   _(user_messages[user_ok]),
 			   NULL,
 			   3000);
@@ -687,9 +687,9 @@ VDKBMainForm::CallEmacsServer(VDKObject*)
 	editor->Visible = false;
     }
   else
-    TheApp->MessageBox(APPNAME,
+    TheApp->VDKMessageBox(APPNAME,
 		       _("Emacs server already running"),
-		       MB_ICONINFORMATION|MB_OK,
+		       VDK_ICONINFORMATION|VDK_OK,
 		       _(user_messages[user_ok]),
 		       NULL,
 		       3000);
@@ -1052,9 +1052,9 @@ VDKBMainForm::NewForm(VDKObject*)
       // FIX ME: user warning on false returned
       sprintf(buff,_("%s done.\nMay be you want add it to project."),
 	      (char*) selections[0]);
-      Application()->MessageBox(APPNAME,
+      Application()->VDKMessageBox(APPNAME,
 				buff,
-				MB_ICONINFORMATION|MB_OK,
+				VDK_ICONINFORMATION|VDK_OK,
 				_(user_messages[user_ok]),
 				NULL,5000);
 
@@ -1082,8 +1082,8 @@ VDKBMainForm::NewProject(VDKObject*)
     {
       sprintf(buff,_("project: %s\nalready exists, overwrite it ?"),
 	      (char*) info.prjname);
-      if(Application()->MessageBox(APPNAME,buff,
-				   MB_ICONQUESTION|MB_YESNO) != IDYES)
+      if(Application()->VDKMessageBox(APPNAME,buff,
+				   VDK_ICONQUESTION|VDK_YESNO) != VDK_IDYES)
 	return true;
     }
   prjman->Raise();
