@@ -65,6 +65,7 @@
 #include <gdk/gdkx.h>
 #include <vdkb2/vdkb_notebook.h>
 #include <vdkb2/vdkb_frame.h>
+
 static char buff[256];
 #define VERBOSE 0
 
@@ -666,9 +667,9 @@ void
 VDKBObject::PopObjectBrowser()
 {
   if(object)
-    object->Owner()->Application()->MessageBox(APPNAME,
+    object->Owner()->Application()->VDKMessageBox(APPNAME,
 					       _("Sorry, not yet implemented"),
-					       MB_OK| MB_ICONINFORMATION);
+					       VDK_OK| VDK_ICONINFORMATION);
 }
 /*
 This should be override by subclasses in order
@@ -817,7 +818,8 @@ VDKBObject::ButtonPressed(VDKObject* sender, GdkEvent* ev)
   stop = ! dynamic_cast<VDKGnomeDateEdit*>(sender);
 #endif
   VDKBGuiNotebook* nbook = dynamic_cast<VDKBGuiNotebook*>(sender);
-  stop = nbook == NULL;
+  if(nbook)
+    stop = false;
   // if(stop)
   //   gtk_signal_emit_stop_by_name(GTK_OBJECT(sender->WrappedWidget()),"button_press_event");
   /*
