@@ -743,14 +743,14 @@ VDKBObjectInspector::OnMultipleConnect(VDKObject*)
 		}
 	      else
 		{
-		Application()->MessageBox(APPNAME, _(wi_prompts[3]),
-					  MB_OK| MB_ICONINFORMATION);
+		Application()->VDKMessageBox(APPNAME, _(wi_prompts[3]),
+					  VDK_OK| VDK_ICONINFORMATION);
 		return true;
 		}
 	    }
 	}
     }
-  Application()->MessageBox(APPNAME,_(wi_prompts[3]), MB_OK| MB_ICONINFORMATION);
+  Application()->VDKMessageBox(APPNAME,_(wi_prompts[3]), VDK_OK| VDK_ICONINFORMATION);
   return true;
 }
 /*
@@ -784,9 +784,9 @@ VDKBObjectInspector::OnConnectSignal(VDKObject* sender)
 		  LoadStaticTable();
 		}
 	      else
-		Application()->MessageBox(APPNAME,
+		Application()->VDKMessageBox(APPNAME,
 					  _(wi_prompts[5]),
-					  MB_OK| MB_ICONINFORMATION);
+					  VDK_OK| VDK_ICONINFORMATION);
 	    }
 	}
     }
@@ -896,8 +896,8 @@ VDKBObjectInspector::SetWidgetName(VDKObject*)
       VDKBGuiForm* owner_form = dynamic_cast<VDKBGuiForm*>(vdkobj->Owner());
       if(owner_form && owner_form->ChildWithName((char*) name->Text))
 	// FIX ME: language support
-	Application()->MessageBox(APPNAME, _(wi_prompts[6]),
-				  MB_OK| MB_ICONINFORMATION);
+	Application()->VDKMessageBox(APPNAME, _(wi_prompts[6]),
+				  VDK_OK| VDK_ICONINFORMATION);
       else if(owner_form && (strlen((char*) name->Text) > 0))
 	{
 	  // widget name is changed so it's
@@ -919,9 +919,9 @@ VDKBObjectInspector::SetWidgetName(VDKObject*)
 	{
 	  // widget name can't be empty
 	  // FIX ME: language support
-	  Application()->MessageBox(APPNAME,
+	  Application()->VDKMessageBox(APPNAME,
 				    _(wi_prompts[7]),
-				    MB_OK| MB_ICONINFORMATION);
+				    VDK_OK| VDK_ICONINFORMATION);
 	  name->Text = (char*) oldWidgetName;
 	}
 
