@@ -1269,7 +1269,7 @@ VDKBParser::CheckXDBSupport(int mode)
       switch(mode)
 	{
 	case 0:
-	  result = mainform->Application()->MessageBox(APPNAME,
+	  result = mainform->Application()->VDKMessageBox(APPNAME,
 				  _("\
 You are constructing a data-aware widget\n\
 without using tables (VDKBuilder tables database is empty).\n\
@@ -1277,14 +1277,14 @@ If you want avoid compilation errors, explicitely define\n\
 VDKXDB_SUPPORT or add the proper table to\n\
 VDKBuilder tables database using \"Tools\" menu.\n\
 Do you want define VDKXDB_SUPPORT now ?"),
-				  MB_ICONQUESTION|MB_YESNO,
+				  VDK_ICONQUESTION|VDK_YESNO,
 				  _(user_messages[user_ok]),
-				  _(user_messages[user_no])) == IDYES;
+				  _(user_messages[user_no])) == VDK_IDYES;
 	  if(result)
 	    (*prj->Options()).defines += " -DVDKXDB_SUPPORT";
 	  break;
 	case 1:
-	  result = mainform->Application()->MessageBox(APPNAME,
+	  result = mainform->Application()->VDKMessageBox(APPNAME,
 					      _("\
 You are assigning a table/field to data-aware widget\n\
 without using tables (VDKBuilder tables database is empty).\n\
@@ -1292,9 +1292,9 @@ If you want avoid compilation errors, explicitely define\n\
 VDKXDB_SUPPORT or add the proper table to\n\
 VDKBuilder tables database using \"Tools\" menu.\n\
 Do you want define VDKXDB_SUPPORT now ?"),
-				  MB_ICONQUESTION|MB_YESNO,
+				  VDK_ICONQUESTION|VDK_YESNO,
 				  _(user_messages[user_ok]),
-				  _(user_messages[user_no])) == IDYES;
+				  _(user_messages[user_no])) == VDK_IDYES;
 	  if( result)
 	    (*prj->Options()).defines += " -DVDKXDB_SUPPORT";
 	  break;
