@@ -676,9 +676,9 @@ VDKBProjectManager::LoadLastSession()
 	  if(access(key,F_OK))
 	    {
 	      sprintf(buff,_("Could not open last session %s"),key);
-	      Application()->MessageBox(APPNAME,
+	      Application()->VDKMessageBox(APPNAME,
 					buff,
-					MB_OK| MB_ICONINFORMATION,
+					VDK_OK| VDK_ICONINFORMATION,
 					_(user_messages[user_cancel]),
 					NULL,5000);
 	      return;
@@ -1355,9 +1355,9 @@ VDKBProjectManager::RemoveUnit()
 	 GTK_CTREE(tree->CustomWidget()), node);
 
   if(unit->Type() == project_unit)
-    Application()->MessageBox(APPNAME,
+    Application()->VDKMessageBox(APPNAME,
 			      _(user_messages[user_cant_remove_unit]),
-			      MB_OK| MB_ICONINFORMATION,
+			      VDK_OK| VDK_ICONINFORMATION,
 			      _(user_messages[user_cancel]));
 
   else if(project->Units().remove(unit))
@@ -1394,9 +1394,9 @@ void VDKBProjectManager::AddUnit()
 		  unit->Name(),
 		  _(user_messages[user_dup_unit])
 		  );
-	  Application()->MessageBox(APPNAME,
+	  Application()->VDKMessageBox(APPNAME,
 				    buff,
-				    MB_OK| MB_ICONINFORMATION,
+				    VDK_OK| VDK_ICONINFORMATION,
 				    _(user_messages[user_cancel]));
 
 	  delete unit;
@@ -1415,9 +1415,9 @@ void VDKBProjectManager::AddUnit()
 		  _(user_messages[user_unknown_unit]),
 		  _(user_messages[user_unknown_unit1])
 		  );
-	  Application()->MessageBox(APPNAME,
+	  Application()->VDKMessageBox(APPNAME,
 				    buff,
-				    MB_OK| MB_ICONINFORMATION,
+				    VDK_OK| VDK_ICONINFORMATION,
 				    _(user_messages[user_cancel])
 				    );
 	  delete unit;
