@@ -873,7 +873,7 @@ VDKBProject::WriteMakefile(FILE* fp)
 \n$(TARGET): $(OBJECTS)\
 \n\t$(LINK)  -o $(TARGET) $(OBJECTS) $(OTHERS_OBJECTS) $(LIBS)\
 \n\
-\n####### Running (used by builder)
+\n####### Running (used by builder)\
 \nrun: $(TARGET)\
 \n\tcd %s\
 \n\t%s $(PRG_ARGS)\
