@@ -800,10 +800,10 @@ CLASS::OnAssignTableButtonClicked(VDKObject*)
       _("VDKXTable field count and VDKXCustomList columns should match.\n\
 Couldn't assign the table"), 
 	      tname);
-      Owner()->Application()->MessageBox(
+      Owner()->Application()->VDKMessageBox(
 					 APPNAME,
 					 buff,
-					 MB_ICONINFORMATION|MB_OK,
+					 VDK_ICONINFORMATION|VDK_OK,
 					 _(user_messages[user_ok]),
 					 NULL,
 					 5000); // warns user
@@ -823,10 +823,10 @@ Couldn't assign the table"),
   else
     {
       sprintf(buff,_("Couldn't assign to table \"%s\""), tname);
-      Owner()->Application()->MessageBox(
+      Owner()->Application()->VDKMessageBox(
 	 APPNAME,
 	 buff,
-	 MB_ICONINFORMATION|MB_OK,
+	 VDK_ICONINFORMATION|VDK_OK,
 	 _(user_messages[user_ok]),
 	 NULL,
 	 5000); // warns user
