@@ -608,10 +608,10 @@ CLASS::OnAssignButtonClicked(VDKObject*)
     {
       sprintf(buff,_("Couldn't assign to field \"%s\" on table %s"),
 	      fname,tname);
-      Owner()->Application()->MessageBox(
+      Owner()->Application()->VDKMessageBox(
 	 APPNAME,
 	 buff,
-	 MB_ICONINFORMATION|MB_OK,
+	 VDK_ICONINFORMATION|VDK_OK,
 	 _(user_messages[user_ok]),
 	 NULL,
 	 5000); // warns user
